@@ -14,7 +14,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 // to contact the author : http://dar.linux.free.fr/email.html
 /*********************************************************************/
@@ -66,27 +66,40 @@ static S_I little_main(shared_ptr<user_interaction> & dialog, S_I argc, char * c
     const char *home = line_tools_get_from_env(env, "HOME");
     deque<string> dar_dcf_path = line_tools_explode_PATH(line_tools_get_from_env(env, "DAR_DCF_PATH"));
     deque<string> dar_duc_path = line_tools_explode_PATH(line_tools_get_from_env(env, "DAR_DUC_PATH"));
-    string sftp_known_hosts = string(home) + "/.ssh/known_hosts";
-    string sftp_pub_filekey = string(home) + "/.ssh/id_rsa.pub";
-    string sftp_prv_filekey = string(home) + "/.ssh/id_rsa";
+    string sftp_known_hosts;
+    string sftp_pub_filekey;
+    string sftp_prv_filekey;
     const char *env_knownhosts = line_tools_get_from_env(env, "DAR_SFTP_KNOWNHOSTS_FILE");
     const char *env_pub_filekey = line_tools_get_from_env(env, "DAR_SFTP_PUBLIC_KEYFILE");
     const char *env_prv_filekey = line_tools_get_from_env(env, "DAR_SFTP_PRIVATE_KEYFILE");
     const char *env_ignored_as_symlink = line_tools_get_from_env(env, "DAR_IGNORED_AS_SYMLINK");
     shell_interaction *shelli = dynamic_cast<shell_interaction *>(dialog.get());
+    string home_pref;
 
     if(!dialog)
 	throw SRC_BUG;
     if(shelli == nullptr)
 	throw SRC_BUG;
     if(home == nullptr)
+    {
         home = "/";
+	home_pref = "";
+    }
+    else
+	home_pref = string(home);
+
     if(env_knownhosts != nullptr)
 	sftp_known_hosts = string(env_knownhosts);
+    else
+	sftp_known_hosts = home_pref + "/.ssh/known_hosts";
     if(env_pub_filekey != nullptr)
 	sftp_pub_filekey = string(env_pub_filekey);
+    else
+	sftp_pub_filekey = home_pref + "/.ssh/id_rsa.pub";
     if(env_prv_filekey != nullptr)
 	sftp_prv_filekey = string(env_prv_filekey);
+    else
+	sftp_prv_filekey = home_pref + "/.ssh/id_rsa";
 
     if(! get_args(dialog,
 		  home,
