@@ -14,7 +14,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 // to contact the author : http://dar.linux.free.fr/email.html
 /*********************************************************************/
@@ -162,7 +162,7 @@ namespace libdar
 		    ret->d_name[max_alloc_filename] = '\0'; // yes, one byte is allocated for the terminal zero
 		    if(strlen(ret->d_name) >= max_alloc_filename)
 		    {
-			ui.message(tools_printf(gettext("Filename provided by the operating system seems truncated in directory %s ignoring it: %s"), dirname, ret->d_name));
+			ui.message(tools_printf(gettext("Filename provided by the operating system seems truncated in directory %s, storing filename as is: %s"), dirname, ret->d_name));
 			continue;
 		    }
 #else
